@@ -69,6 +69,7 @@ class Client:
                 url=clear_endpoint,
                 data=data,
                 headers=headers,
+                query_params=query_params,
                 **kwargs
             )
         elif method == Client.Method.PATCH:
@@ -76,6 +77,7 @@ class Client:
                 url=clear_endpoint,
                 data=data,
                 headers=headers,
+                query_params=query_params,
                 **kwargs
             )
         elif method == Client.Method.DELETE:
@@ -83,6 +85,7 @@ class Client:
                 url=clear_endpoint,
                 data=data,
                 headers=headers,
+                query_params=query_params,
                 **kwargs
             )
 
@@ -105,25 +108,28 @@ class Client:
         )
 
     @staticmethod
-    def _put(url, data, **kwargs) -> requests.Response:
+    def _put(url, data, query_params, **kwargs) -> requests.Response:
         return requests.put(
             url=url,
             data=data,
+            params=query_params,
             **kwargs
         )
 
     @staticmethod
-    def _patch(url, data, **kwargs) -> requests.Response:
+    def _patch(url, data, query_params, **kwargs) -> requests.Response:
         return requests.patch(
             url=url,
             data=data,
+            params=query_params,
             **kwargs
         )
 
     @staticmethod
-    def _delete(url, data, **kwargs) -> requests.Response:
+    def _delete(url, query_params, data, **kwargs) -> requests.Response:
         return requests.delete(
             url=url,
             data=data,
+            params=query_params,
             **kwargs
         )
