@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+
+
 import telegram
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
@@ -27,8 +30,6 @@ class Bot(telegram.Bot):
         super(Bot, self).__init__(token=token)
 
     def send_message(self, chat_id, text, parse_mode=None, **kwargs):
-        if parse_mode is None:
-            parse_mode = self._DEFAULT_PARSE_MODE
         return super(Bot, self).send_message(
             chat_id=chat_id,
             text=text,
