@@ -19,7 +19,7 @@ def mock(func_list: dict, condition: str):
                     return func_list.get('staging', func)(*args, **kwargs)
                 elif condition.lower() == 'production':  # pragma: no cover
                     return func_list.get('production', func)(*args, **kwargs)
-            return func(*args, *kwargs)
+            return func(*args, **kwargs)
 
         return inner
 
