@@ -1,7 +1,7 @@
 from rest_framework.permissions import BasePermission
 
 
-class HolgerPermission(BasePermission):
+class TamarinPermission(BasePermission):
 
     def __init__(self, **kwargs):
         for key, value in kwargs.items():
